@@ -15,6 +15,7 @@ from canvas_workflow_kit.patient_recordset import (
     BillingLineItemRecordSet,
     ConditionRecordSet,
     ConsentRecordSet,
+    ExternalEventRecordSet,
     GroupRecordSet,
     ImagingReportRecordSet,
     ImmunizationRecordSet,
@@ -65,6 +66,7 @@ class Patient:
         BillingLineItemRecordSet,
         ConditionRecordSet,
         ConsentRecordSet,
+        ExternalEventRecordSet,
         GroupRecordSet,
         ImagingReportRecordSet,
         ImmunizationRecordSet,
@@ -108,6 +110,9 @@ class Patient:
         self.consents = ConsentRecordSet.new_from(
             data.get(ConsentRecordSet.API_UPDATE_FIELD, []))
 
+        self.external_events = ExternalEventRecordSet.new_from(
+            data.get(ExternalEventRecordSet.API_UPDATE_FIELD, []))
+
         self.groups = GroupRecordSet.new_from(
             data.get(GroupRecordSet.API_UPDATE_FIELD, []))
 
