@@ -831,3 +831,9 @@ class GroupRecordSet(PatientRecordSet):
     PATIENT_FIELD = 'groups'
     API_UPDATE_FIELD = 'groups'
 
+
+class ExternalEventRecordSet(PatientEventRecordSet):
+    PATIENT_FIELD = 'external_events'
+    API_UPDATE_FIELD = 'externalEvents'
+    DATE_FIELD = 'eventDatetime'
+
