@@ -85,6 +85,7 @@ class TestPatient(SDKBaseTest):
             'billing_line_items': 2,
             'conditions': 3,
             'consents': 2,
+            'external_events': 1,
             'groups': 1,
             'imaging_reports': 2,
             'immunizations': 1,
@@ -110,12 +111,13 @@ class TestPatient(SDKBaseTest):
     def test_recordset_classes(self):
         tested = self.load_patient('full')
         expected = [
-            'AppointmentRecordSet',
             'AdministrativeDocumentRecordSet',
             'AllergyIntoleranceRecordSet',
+            'AppointmentRecordSet',
             'BillingLineItemRecordSet',
             'ConditionRecordSet',
             'ConsentRecordSet',
+            'ExternalEventRecordSet',
             'GroupRecordSet',
             'ImagingReportRecordSet',
             'ImmunizationRecordSet',
@@ -151,6 +153,7 @@ class TestPatient(SDKBaseTest):
             'billing_line_items',
             'conditions',
             'consents',
+            'external_events',
             'groups',
             'imaging_reports',
             'immunizations',
@@ -361,6 +364,7 @@ class TestPatient(SDKBaseTest):
             'billing_line_items',
             'conditions',
             'consents',
+            'external_events',
             'groups',
             'imaging_reports',
             'immunizations',
